<?php
/*
Plugin Name: Archives Calendar Widget
Plugin URI: http://labs.alek.be/
Description: Display archives as calendar.
Version: 0.2.3
Author: Aleksei Polechin (alek´)
Author URI: http://alek.be
License: GPLv3

/***** LICENSE *****

	Archives Calendar Widget for Wordpress
	Copyright (C) 2013  Aleksei Polechin (http://alek.be)

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
****/

// ACTIVATION
function archivesCalendar_activation($network_wide){
	global $wpdb;
	if (isMU()){ //isMU verifyes id the site is in Multisite mode
		// check if it is a network activation - if so, run the activation function for each blog id
		if (isset($_GET['networkwide']) && ($_GET['networkwide'] == 1)) {
			$old_blog = $wpdb->blogid;
			// Get all blog ids
			$blogids =  $wpdb->get_results("SELECT blog_id FROM $wpdb->blogs");
			foreach ($blogids as $blogid) {
				$blog_id = $blogid->blog_id;
				switch_to_blog($blog_id);
				_archivesCalendar_activate();
			}
			switch_to_blog($old_blog);
			return;
		}   
	} 
	_archivesCalendar_activate();
}
function _archivesCalendar_activate(){
	global $wpdb;	
	if(!get_option( 'archivesCalendar' ))
		$options = array("css" => 1, "jquery" => 0, "js" => 1, "show_settings" => 1);
	else
		$options = get_option( 'archivesCalendar' );
		
	if(isMU()) {
		update_blog_option($wpdb -> blogid, 'archivesCalendar', $options);
		add_blog_option($wpdb -> blogid, 'archivesCalendar', $options);
	}
	else {
		update_option('archivesCalendar', $options);
		add_option('archivesCalendar', $options);
	}
}
register_activation_hook(__FILE__, 'archivesCalendar_activation');

function archivesCalendar_new_blog($blog_id) {
	global $wpdb;
	if (is_plugin_active_for_network('archives-calendar/archives-calendar.php')) {
		$old_blog = $wpdb->blogid;
		switch_to_blog($blog_id);
		_archivesCalendar_activate();
		switch_to_blog($old_blog);
	}
}
add_action( 'wpmu_new_blog', 'archivesCalendar_new_blog', 10, 6); // in case of creation of a new site in WPMU


// UNINSTALL 
function archivesCalendar_uninstall(){
	global $wpdb;
   if (isMU()) {
		$old_blog = $wpdb->blogid;
		$blogids =  $wpdb->get_results("SELECT blog_id FROM $wpdb->blogs");
		foreach ($blogids as $blogid) {
			$blog_id = $blogid->blog_id;
			switch_to_blog($blog_id);
			_archivesCalendar_uninstall();
		}
		switch_to_blog($old_blog);
		return;
	} 
	_archivesCalendar_uninstall();
}
function _archivesCalendar_uninstall(){
	global $wpdb;
	if (isMU()) delete_blog_option($wpdb->blogid, 'archivesCalendar');
	else delete_option('archivesCalendar');
}
register_uninstall_hook(__FILE__, 'archivesCalendar_uninstall');

// ADD Settings link in Plugins page when the plugin is activated
if(!function_exists('plugin_settings_link')){
	function plugin_settings_link($links) {
		$settings_link = '<a href="options-general.php?page=archives_calendar">Settings</a>'; 
		array_unshift($links, $settings_link); 
		return $links; 
	}
}
$acplugin = plugin_basename( __FILE__ );
add_filter( "plugin_action_links_$acplugin", 'plugin_settings_link' );


$archivesCalendar_options = get_option('archivesCalendar');

function archivesCalendar_jquery() {
    wp_enqueue_script('jquery');
}
function calendar_archives_js() {
	?>
	<script type="text/javascript">
		jQuery(document).ready(function($){$wearein=$('.calendar-archives .current.year').attr('rel');$('.calendar-archives .prev-year').on('click',function(e){e.preventDefault();$('.calendar-archives .year[rel='+$wearein+']').animate({opacity:.5},300);$wearein-=1;$('.calendar-archives .year[rel='+$wearein+']').animate({left:0},300)});$('.calendar-archives .next-year').on('click',function(e){e.preventDefault();$('.calendar-archives .year[rel='+$wearein+']').animate({left:'-100%'},300);$wearein+=1;$('.calendar-archives .year[rel='+$wearein+']').animate({opacity:1},300)})});
	</script>
	<?php
}
if($archivesCalendar_options['css'] == 1){
	wp_register_style( 'archives-cal-css', plugins_url('archives-calendar.css', __FILE__));
	wp_enqueue_style('archives-cal-css');
}
if($archivesCalendar_options['js'] == 1) add_action('wp_head', 'calendar_archives_js');
if($archivesCalendar_options['jquery'] == 1) add_action( 'wp_enqueue_scripts', 'archivesCalendar_jquery' );




/***** WIDGET CLASS *****/
class Archives_Calendar extends WP_Widget {
	public function __construct() {
		parent::__construct(
	 		'archives_calendar',
			'Archives Calendar',
			array( 'description' => __( 'Show archives as calendar', 'archives_calendar' ), )
		);
	}
	public function widget( $args, $instance ) {
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo $before_widget;
		if ( ! empty( $title ) )
			echo $before_title . $title . $after_title;
		archive_calendar($instance);
		echo $after_widget;
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['prev_text'] = $new_instance['prev_text'];
		$instance['next_text'] = $new_instance['next_text'];
		$instance['post_count'] = $new_instance['post_count'];
		return $instance;
	}

	public function form( $instance ) {
		$defaults = array(
			'title'      => __( 'Archives' ),
			'next_text' => '>',
			'prev_text' => '<',
			'post_count' => 1,
		);
		$instance = wp_parse_args( (array) $instance, $defaults );
		$title = $instance['title'];
		$prev = $instance['prev_text'];
		$next = $instance['next_text'];
		$count = $instance['post_count'];
		?>
		<p>
		<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
		<label for="<?php echo $this->get_field_id( 'prev_text' ); ?>"><?php _e( 'Previous button text:', 'archives_calendar' ); ?></label> 
		<input class="widefat" id="<?php echo $this->get_field_id( 'prev_text' ); ?>" name="<?php echo $this->get_field_name( 'prev_text' ); ?>" type="text" value="<?php echo esc_attr( $prev ); ?>" />
		<label for="<?php echo $this->get_field_id( 'next_text' ); ?>"><?php _e( 'Next button text:', 'archives_calendar' ); ?></label> 
		<input class="widefat" id="<?php echo $this->get_field_id( 'next_text' ); ?>" name="<?php echo $this->get_field_name( 'next_text' ); ?>" type="text" value="<?php echo esc_attr( $next ); ?>" />
		</p>
		<p>
		<label for="<?php echo $this->get_field_id( 'post_count' ); ?>"><?php _e( 'Show number of posts:' ); ?></label> 
		<select name="<?php echo $this->get_field_name( 'post_count' ); ?>" >
			<option <?php selected( 1, $count ); ?> value="1">
				<?php _e( 'Yes', 'archives_calendar' ); ?>
			</option>
			<option <?php selected( 0, $count ); ?> value="0">
				<?php _e( 'No', 'archives_calendar' ); ?>
			</option>
		</select>
		</p>
		<?php 
	}
}
add_action( 'widgets_init', create_function( '', 'register_widget( "Archives_Calendar" );' ) );

/***** WIDGET CONSTRUCTION FUNCTION *****/
/* can be called directly archive_calendar($args) */
function archive_calendar($args = array()) {
	global $wpdb;
	setlocale(LC_ALL, WPLANG);
	$defaults = array(
		'next_text' => '>',
		'prev_text' => '<',
		'post_count' => true,
	);
	$args = wp_parse_args( (array) $args, $defaults );
	extract($args);
		
	$results = $wpdb->get_results("SELECT DISTINCT YEAR(post_date) AS year, MONTH(post_date) AS month FROM $wpdb->posts WHERE post_type='post' AND post_status='publish' AND post_password='' ORDER BY year DESC, month DESC");
	
	$years = array();
	foreach ($results as $date) {
		if($post_count){
			$postcount = $wpdb->get_results("SELECT COUNT(ID) AS count FROM $wpdb->posts WHERE post_type='post' AND post_status='publish' AND post_password='' AND YEAR(post_date) = $date->year AND MONTH(post_date) = $date->month");
			$count = $postcount[0]->count;
		}
		else $count = 0;
		$years[$date->year][$date->month] = $count;
	}
	
	$wearein = date('Y');
	$nbyears = count($years);
	$i=$nbyears;
	
	$nextyear = '<a href="#" class="next-year"><span>'.$next_text.'</span></a>';
	$prevyear = '<a href="#" class="prev-year"><span>'.$prev_text.'</span></a>';
		
	$cal = '<div class="calendar-archives">';
	foreach ($years as $year => $months){
		if($wearein == $year) $current = " current";
		else $current = "";

		$cal .= '<div class="year '.$year.$current.'" rel="'.$i.'"><div class="year-nav">';
		if($nbyears > 1 && $i <= $nbyears && $i > 1)
			$cal .= $prevyear;
		$cal .= '<a href="'.get_year_link($year).'" class="year-link"><span>'.$year.'</span></a>';
		if($nbyears > 1 && $year < $wearein && $i >= 1)
			$cal .= $nextyear;
		$cal .= '</div><div>';
		for ( $month = 1; $month <= 12; $month++ ) {
			if( $month%4 == 0 ) $last = ' last';
			else $last = '';
			
			if($post_count) {
				if(isset($months[$month])) $count = $months[$month];
				else $count = 0;
				$postcount = '<span class="postcount"><span class="count-number">'.$count.'</span> <span class="count-text">'.__('Posts', 'archives_calendar').'</span></span>';
			}
			else $postcount = "";

			if(isset($months[$month])){
				$cal .= '<div class="month'.$last.'"><a href="'.get_month_link($year, $month).'"><span class="month-name">'.strftime("%b", strtotime($month."/01/1970")).'</span>'.$postcount.'</a></div>';
			}
			else  $cal .= '<div class="month'.$last.' empty"><span class="month-name">'.strftime("%b", strtotime($month."/01/1970")).'</span>'.$postcount.'</div>';
		}
		$cal .= "</div></div>\n";
		$i--;
	}
	$cal .= "</div>";
	echo "\n<!-- Archives Calendar widget by Aleksei Polechin - http://alek.be -->\n";
	echo $cal;
}



/***** SETTINGS ******/
function archivesCalendar_admin_init(){
	register_setting( 'archivesCalendar_options', 'archivesCalendar', 'archivesCalendar_options_validate' );
	add_settings_section('archivesCalendar_main', '', 'archivesCalendar_options', 'archivesCalendar_plugin');
}
add_action('admin_init', 'archivesCalendar_admin_init');

function ArchivesCalandarSettingsMenu() {
	global $archivesCalendar_options;
	if($archivesCalendar_options['show_settings'] == 1) $menu_name = 'Archives Calendar';
	else $menu_name = '';
	add_options_page('Archives Calendar Settings', $menu_name, 'manage_options', 'archives_calendar', 'archives_calendar_settings');
}

function archivesCalendar_options_validate($args) {
	if(!isset($args['show_settings'])) $args['show_settings'] = 0;
	else $args['show_settings'] = 1;
	if(!isset($args['css'])) $args['css'] = 0;
	else $args['css'] = 1;
	if(!isset($args['jquery'])) $args['jquery'] = 0;
	else $args['jquery'] = 1;
	if(!isset($args['js'])) $args['js'] = 0;
	else $args['js'] = 1;
	return $args;
}

function archives_calendar_settings(){?>
	<div class="wrap">
	<div class="icon32"><img src="<?php echo plugins_url('icon32.png', __FILE__);?>" /></div>
	<h2><?php _e('Archives Calendar Settings', 'archives_calendar');?></h2>
	<form method="post" action="options.php">
		<?php
		settings_fields('archivesCalendar_options');
		do_settings_sections('archivesCalendar_plugin');	
		?>			
	</form>
	</div>
	<?php 
}
add_action('admin_menu', 'ArchivesCalandarSettingsMenu');

function archivesCalendar_options(){
	$options = get_option('archivesCalendar');
	?>
	<style>
		pre{font-size:11px; padding:10px; border:#CCC 1px solid; background:#f1f1f1; overflow:auto;}
		label{font-weight:bold;}
	</style>
	<div id="poststuff">
		<div id="post-body" class="metabox-holder columns-2">
			<div id="post-body-content">
				<p>
					<input type="checkbox" id="css" name="archivesCalendar[css]" <?php ac_checked('css');?> /> <label for="css">Include default CSS file</label><br />
					<span class="description">Include "archives-calendar.css" from the plugin. Uncheck if you copy the CSS code to your theme's style.css (<strong>recommended</strong>).<br />
					<strong>NOTE:</strong> if you have modified the default CSS file it will be restored on next plugin update.</span>
				</p>
				<p>
					<input type="checkbox" id="jquery" name="archivesCalendar[jquery]" <?php ac_checked('jquery');?> /> <label for="jquery">Include jQuery library</label><br />
					<span class="description">Include jQuery library into you theme. Uncheck it if you already use jQuery in your theme.<br />
					<strong>NOTE:</strong> jQuery is required to be able to change archives year, elsewhere you will only see the current year.</span>
				</p>
				<p>
					<input type="checkbox" id="js" name="archivesCalendar[js]" <?php ac_checked('js');?> /> <label for="js">Insert JavaScript code into &lt;head&gt;</label><br />
					<span class="description">Insert javascript code into the head. Uncheck only if you copy the code into your default js file.<br />
					<strong>NOTE:</strong>this code is required to be able to change archive year, elsewhere you will only see the current year.</span>
					<div style="margin-left:50px;"><h5 class="title">Default javascript:</h5>
<pre>$(document).ready(function(e) {
	$wearein = $('.calendar-archives .current.year').attr('rel');
	$('.calendar-archives .prev-year').on('click', function(e){
		e.preventDefault();
		$('.calendar-archives .year[rel='+$wearein+']').animate({opacity: .5},300);
		$wearein -= 1;
		$('.calendar-archives .year[rel='+$wearein+']').animate({left: 0},300);
	});
	$('.calendar-archives .next-year').on('click', function(e){
		e.preventDefault();	
		$('.calendar-archives .year[rel='+$wearein+']').animate({left: '-100%'},300);
		$wearein += 1;
		$('.calendar-archives .year[rel='+$wearein+']').animate({opacity: 1},300);
	});
});</pre>
					</div>
				</p>
				<hr />
				<p>
					<input type="checkbox" id="soptions" name="archivesCalendar[show_settings]" <?php ac_checked('show_settings');?> /> <label for="soptions">Show link to Settings in admin menu</label><br />
					<span class="description">Show link "Archives Calendar" in admin "Settings" menu. If unchecked you can enter settings from "Settings" link in "Plugins" page.</span>
				</p>

				<p>
					<input name="Submit" type="submit" class="button-primary" value="<?php _e('Save settings', 'archives_calendar') ?>" />
				</p>
			</div>
			<div id="postbox-container-1" class="postbox-container">
				<div id="submitdiv" class="postbox ">
					<div class="inside" style="padding:15px;">
						<h2 style="font-size:24px; margin:0;"><?php _e('Donate', 'archives_calendar');?></h2>
							<p>
								<?php _e('If you like this plugin and find it useful, consider donating to support my work by clicking on "Donate" button.', 'archives_calendar');?>
							</p>
							<p>
								<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=4K6STJNLKBTMU" target="_blank"><img src="https://www.paypalobjects.com/en_US/BE/i/btn/btn_donateCC_LG.gif" alt="Donate" /></a>
							</p>
					</div>
				</div>
			</div>
		</div>
	</div>
	<?php
}

function ac_checked($option, $value = 1){
	$options = get_option('archivesCalendar');
	if($options[$option] == $value) echo 'checked="checked"';
}

if (!function_exists('isMU')){
	function isMU(){
		if (function_exists('is_multisite') && is_multisite()) return true;
		else return false;
	}
}
?>